package com.gic.haoban.manage.web.controller;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.gic.cloud.common.api.base.Page;
import com.gic.cloud.data.api.dto.AdsGicLogHaobanStoreIntervalLoginDDTO;
import com.gic.cloud.data.api.dto.AdsGicLogHaobanStoreLoginDDTO;
import com.gic.cloud.data.api.dto.AreaLoginDTO;
import com.gic.cloud.data.api.dto.HaobanClerkLoginDTO;
import com.gic.cloud.data.api.dto.HaobanLoginInfoDTO;
import com.gic.cloud.data.api.dto.MemberAnalyzeParamsDTO;
import com.gic.cloud.data.api.service.MaidianDataService;
import com.gic.cloud.web.service.api.dto.CloudStoreGroupDTO;
import com.gic.cloud.web.service.api.service.CloudStoreGroupService;
import com.gic.commons.util.EntityUtil;
import com.gic.haoban.common.utils.HaobanResponse;
import com.gic.haoban.manage.web.errCode.HaoBanErrCode;

@RestController
@RequestMapping("web")
public class MaidianDataController extends WebBaseController{
	
private static Logger logger = LoggerFactory.getLogger(MaidianDataController.class);
	
	@Autowired
	private MaidianDataService maidianDataService;
	@Autowired
	private CloudStoreGroupService cloudStoreGroupService;
	//首页-企业概况
    @RequestMapping("/cloud-grouplist-pid")
    public HaobanResponse cloudGrouplistPid(String enterpriseId) {
        Map<String, Object> returnMap = new HashMap<String, Object>();
        List<CloudStoreGroupDTO> list = cloudStoreGroupService.queryAllStoreGroupByStoreGroupId(enterpriseId);
        returnMap.put("list", list);
        return resultResponse(HaoBanErrCode.ERR_1,returnMap);
    }
	//首页-企业概况
    @RequestMapping("/total-activation-data")
    public HaobanResponse totalActivationData(MemberAnalyzeParamsDTO paramsDTO) {
        Map<String, Object> returnMap = new HashMap<String, Object>();
        AdsGicLogHaobanStoreLoginDDTO dto = maidianDataService.totalActivationData(paramsDTO);
        returnMap.put("loginClerkCnt", dto.getLoginClerkCnt()) ;
        returnMap.put("activeClerkCnt", dto.getActiveClerkCnt()) ;
        returnMap.put("loginClerkTimes", dto.getLoginClerkTimes()) ;
        returnMap.put("notActivieClerkCnt", dto.getNotActivieClerkCnt()) ;
        returnMap.put("totalClerkCnt", dto.getTotalClerkCnt()) ;
        returnMap.put("notLoginClerkCnt", dto.getNotLoginClerkCnt()) ;
        returnMap.put("stayTime", dto.getStayTime()) ;
    	return resultResponse(HaoBanErrCode.ERR_1,returnMap);
    }
    //首页-好办登陆信息总人数概况
    @RequestMapping("/total-login-data")
    public HaobanResponse totalLoginData(MemberAnalyzeParamsDTO paramsDTO,int datesType) {
        Map<String, Object> returnMap = new HashMap<String, Object>();
        List<HaobanLoginInfoDTO> resultList = new ArrayList<HaobanLoginInfoDTO>();
        if(datesType == 1){
        	//近7日
        	List<AdsGicLogHaobanStoreLoginDDTO> list = maidianDataService.totalLoginData(paramsDTO);
        	resultList = EntityUtil.changeEntityListByJSON(HaobanLoginInfoDTO.class, list);
        }else {
        	//当日
        	List<AdsGicLogHaobanStoreIntervalLoginDDTO> list = maidianDataService.totalLoginInternalData(paramsDTO);
        	resultList = EntityUtil.changeEntityListByJSON(HaobanLoginInfoDTO.class, list);
        }
        for(HaobanLoginInfoDTO dto : resultList){
        	dto.setAvgVisitTime((double)dto.getStayTime()/dto.getLoginClerkCnt()+"");
        	dto.setAvgLoginTimes((double)dto.getLoginClerkTimes()/dto.getLoginClerkCnt()+"");
        }
        returnMap.put("result", resultList) ;
    	return resultResponse(HaoBanErrCode.ERR_1,returnMap);
    }
    //首页-区域排行
    @RequestMapping("/area-login-ranking")
    public HaobanResponse areaLoginRanking(MemberAnalyzeParamsDTO paramsDTO,int datesType) {
        Map<String, Object> returnMap = new HashMap<String, Object>();
        List<AreaLoginDTO> list = maidianDataService.areaLoginRanking(paramsDTO);
        returnMap.put("result", list) ;
    	return resultResponse(HaoBanErrCode.ERR_1,returnMap);
    }
    //激活明细-激活趋势图
    @RequestMapping("/activite-date")
    public HaobanResponse activiteDate(MemberAnalyzeParamsDTO paramsDTO,int datesType) {
        Map<String, Object> returnMap = new HashMap<String, Object>();
        List<HaobanLoginInfoDTO> resultList = new ArrayList<HaobanLoginInfoDTO>();
        //近7日
    	List<AdsGicLogHaobanStoreLoginDDTO> list = maidianDataService.totalLoginData(paramsDTO);
    	resultList = EntityUtil.changeEntityListByJSON(HaobanLoginInfoDTO.class, list);
        returnMap.put("result", resultList) ;
    	return resultResponse(HaoBanErrCode.ERR_1,returnMap);
    }
    
    //激活明细-激活列表
    @RequestMapping("/activite-list")
    public HaobanResponse activiteList(MemberAnalyzeParamsDTO paramsDTO,int datesType) {
        Map<String, Object> returnMap = new HashMap<String, Object>();
        List<HaobanLoginInfoDTO> resultList = new ArrayList<HaobanLoginInfoDTO>();
        Page<HaobanClerkLoginDTO> page= maidianDataService.pageActiviteList(paramsDTO);
    	resultList = EntityUtil.changeEntityListByJSON(HaobanLoginInfoDTO.class, page);
        returnMap.put("result", resultList) ;
    	return resultResponse(HaoBanErrCode.ERR_1,returnMap);

    }
    
    //登陆明细-明细列表
    @RequestMapping("/login-detail-list")
    public HaobanResponse loginDetailList(MemberAnalyzeParamsDTO paramsDTO,int datesType) {
    	//默认排序
    	if(StringUtils.isEmpty(paramsDTO.getSortColumn())) {
    		paramsDTO.setSortColumn("lastLoginTime");
    	}
    	if(StringUtils.isEmpty(paramsDTO.getSortType())) {
    		paramsDTO.setSortType("desc");
    	}
        Map<String, Object> returnMap = new HashMap<String, Object>();
        Page<HaobanClerkLoginDTO> page= maidianDataService.pageClerkLogin(paramsDTO);
        returnMap.put("result", page) ;
    	return resultResponse(HaoBanErrCode.ERR_1,returnMap);
    }
    
    //区域排行-区域图表
    @RequestMapping("area-ranking-date")
    public HaobanResponse areaRankingDate(MemberAnalyzeParamsDTO paramsDTO,int datesType) {
        Map<String, Object> returnMap = new HashMap<String, Object>();
        List<AreaLoginDTO> list = maidianDataService.areaRankingDate(paramsDTO);
        returnMap.put("result", list) ;
    	return resultResponse(HaoBanErrCode.ERR_1,returnMap);
    }
    
    //区域排行-区域列表
    @RequestMapping("/area-ranking-list")
    public HaobanResponse areaRankingList(MemberAnalyzeParamsDTO paramsDTO,int datesType) {
    	//默认排序
    	if(StringUtils.isEmpty(paramsDTO.getSortColumn())) {
    		paramsDTO.setSortColumn("loginRate");
    	}
    	if(StringUtils.isEmpty(paramsDTO.getSortType())) {
    		paramsDTO.setSortType("desc");
    	}
        Map<String, Object> returnMap = new HashMap<String, Object>();
        Page<AreaLoginDTO> page = maidianDataService.areaRankingList(paramsDTO);
        returnMap.put("result", page) ;
    	return resultResponse(HaoBanErrCode.ERR_1,returnMap);
    }

}
